<a id="packages.valory.connections.abci.dialogues"></a>

# packages.valory.connections.abci.dialogues

Dialogues classes for the ABCI connection.

<a id="packages.valory.connections.abci.dialogues.AbciDialogues"></a>

## AbciDialogues Objects

```python
class AbciDialogues(BaseAbciDialogues)
```

The dialogues class keeps track of all ABCI dialogues.

<a id="packages.valory.connections.abci.dialogues.AbciDialogues.__init__"></a>

#### `__`init`__`

```python
def __init__() -> None
```

Initialize dialogues.

